==> kinetophone-0.4.0.tar.gz: kinetophone-0.4.0/src/vox/Kinetophone_vox_view.hpp <==
// Kinetophone_vox_view.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef KINETOPHONE_VOX_VIEW_HPP_
#define KINETOPHONE_VOX_VIEW_HPP_

#include <string>

namespace Roan_trail
{
  class Error;

  namespace Kinetophone
  {
    class Kinetophone_vox_view
    {
    public:
      // constructor/destructor
      Kinetophone_vox_view() {}
      // commands
      static void output_message(const std::string& message);
      static void output_error(const Error* error);
      static void output_error(const std::string& message);
    protected:
      // invariant check
      bool mf_invariant(bool check_base_class = true) const;
    private:
      // prevent compiler from generating
      Kinetophone_vox_view(const Kinetophone_vox_view& app);
      Kinetophone_vox_view& operator=(const Kinetophone_vox_view& app);
    };
  }
}

#endif // KINETOPHONE_VOX_VIEW_HPP_

==> kinetophone-0.5.0.tar.gz: kinetophone-0.5.0/src/vox/Kinetophone_vox_view.hpp <==
// Kinetophone_vox_view.hpp
//
// Copyright 2011-2013 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_VIEW_HPP_
#define ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_VIEW_HPP_

#include <string>

namespace Roan_trail
{
  namespace Kinetophone
  {
    class Error;
  }

  namespace Kinetophone_app
  {
    class Kinetophone_vox_view
    {
    public:
      // constructor/destructor
      Kinetophone_vox_view() {}
      // commands
      static void output_message(const std::string& message);
      static void output_error(const Roan_trail::Kinetophone::Error* error);
      static void output_error(const std::string& message);
    protected:
      // invariant check
      bool mf_invariant(bool check_base_class = true) const;
    private:
      // prevent compiler from generating
      Kinetophone_vox_view(const Kinetophone_vox_view& app);
      Kinetophone_vox_view& operator=(const Kinetophone_vox_view& app);
    };
  }
}

#endif // ROAN_TRAIL_KINETOPHONE_APP_KINETOPHONE_VOX_VIEW_HPP_
